@@ -47,11 +47,15 @@ enum generic
     Generic_Duration_String1,
     Generic_Duration_String2,
     Generic_Duration_String3,
+    Generic_Duration_String4,
+    Generic_Duration_String5,
     Generic_Source_Duration,
     Generic_Source_Duration_String,
     Generic_Source_Duration_String1,
     Generic_Source_Duration_String2,
     Generic_Source_Duration_String3,
+    Generic_Source_Duration_String4,
+    Generic_Source_Duration_String5,
     Generic_BitRate_Mode,
     Generic_BitRate_Mode_String,
     Generic_BitRate,
@@ -64,6 +68,8 @@ enum generic
     Generic_BitRate_Maximum_String,
     Generic_BitRate_Encoded,
     Generic_BitRate_Encoded_String,
+    Generic_FrameRate,
+    Generic_FrameRate_String,
     Generic_FrameCount,
     Generic_Source_FrameCount,
     Generic_ColorSpace,
@@ -81,6 +87,7 @@ enum generic
     Generic_Delay_String2,
     Generic_Delay_String3,
     Generic_Delay_String4,
+    Generic_Delay_String5,
     Generic_Delay_Settings,
     Generic_Delay_DropFrame,
     Generic_Delay_Source,
@@ -91,6 +98,7 @@ enum generic
     Generic_Delay_Original_String2,
     Generic_Delay_Original_String3,
     Generic_Delay_Original_String4,
+    Generic_Delay_Original_String5,
     Generic_Delay_Original_Settings,
     Generic_Delay_Original_DropFrame,
     Generic_Delay_Original_Source,
@@ -100,6 +108,7 @@ enum generic
     Generic_Video_Delay_String2,
     Generic_Video_Delay_String3,
     Generic_Video_Delay_String4,
+    Generic_Video_Delay_String5,
     Generic_StreamSize,
     Generic_StreamSize_String,
     Generic_StreamSize_String1,
@@ -232,6 +241,8 @@ enum general
     General_Duration_String1,
     General_Duration_String2,
     General_Duration_String3,
+    General_Duration_String4,
+    General_Duration_String5,
     General_Duration_Start,
     General_Duration_End,
     General_OverallBitRate_Mode,
@@ -244,11 +255,20 @@ enum general
     General_OverallBitRate_Nominal_String,
     General_OverallBitRate_Maximum,
     General_OverallBitRate_Maximum_String,
+    General_FrameRate,
+    General_FrameRate_String,
+    General_FrameCount,
     General_Delay,
     General_Delay_String,
     General_Delay_String1,
     General_Delay_String2,
     General_Delay_String3,
+    General_Delay_String4,
+    General_Delay_String5,
+    General_Delay_Settings,
+    General_Delay_DropFrame,
+    General_Delay_Source,
+    General_Delay_Source_String,
     General_StreamSize,
     General_StreamSize_String,
     General_StreamSize_String1,
@@ -322,6 +342,7 @@ enum general
     General_Original_Lyricist,
     General_Conductor,
     General_Director,
+    General_CoDirector,
     General_AssistantDirector,
     General_DirectorOfPhotography,
     General_SoundEngineer,
@@ -513,31 +534,42 @@ enum video
     Video_Duration_String2,
     Video_Duration_String3,
     Video_Duration_String4,
+    Video_Duration_String5,
     Video_Duration_FirstFrame,
     Video_Duration_FirstFrame_String,
     Video_Duration_FirstFrame_String1,
     Video_Duration_FirstFrame_String2,
     Video_Duration_FirstFrame_String3,
+    Video_Duration_FirstFrame_String4,
+    Video_Duration_FirstFrame_String5,
     Video_Duration_LastFrame,
     Video_Duration_LastFrame_String,
     Video_Duration_LastFrame_String1,
     Video_Duration_LastFrame_String2,
     Video_Duration_LastFrame_String3,
+    Video_Duration_LastFrame_String4,
+    Video_Duration_LastFrame_String5,
     Video_Source_Duration,
     Video_Source_Duration_String,
     Video_Source_Duration_String1,
     Video_Source_Duration_String2,
     Video_Source_Duration_String3,
+    Video_Source_Duration_String4,
+    Video_Source_Duration_String5,
     Video_Source_Duration_FirstFrame,
     Video_Source_Duration_FirstFrame_String,
     Video_Source_Duration_FirstFrame_String1,
     Video_Source_Duration_FirstFrame_String2,
     Video_Source_Duration_FirstFrame_String3,
+    Video_Source_Duration_FirstFrame_String4,
+    Video_Source_Duration_FirstFrame_String5,
     Video_Source_Duration_LastFrame,
     Video_Source_Duration_LastFrame_String,
     Video_Source_Duration_LastFrame_String1,
     Video_Source_Duration_LastFrame_String2,
     Video_Source_Duration_LastFrame_String3,
+    Video_Source_Duration_LastFrame_String4,
+    Video_Source_Duration_LastFrame_String5,
     Video_BitRate_Mode,
     Video_BitRate_Mode_String,
     Video_BitRate,
@@ -625,6 +657,7 @@ enum video
     Video_Delay_String2,
     Video_Delay_String3,
     Video_Delay_String4,
+    Video_Delay_String5,
     Video_Delay_Settings,
     Video_Delay_DropFrame,
     Video_Delay_Source,
@@ -635,6 +668,7 @@ enum video
     Video_Delay_Original_String2,
     Video_Delay_Original_String3,
     Video_Delay_Original_String4,
+    Video_Delay_Original_String5,
     Video_Delay_Original_Settings,
     Video_Delay_Original_DropFrame,
     Video_Delay_Original_Source,
@@ -643,9 +677,15 @@ enum video
     Video_TimeStamp_FirstFrame_String1,
     Video_TimeStamp_FirstFrame_String2,
     Video_TimeStamp_FirstFrame_String3,
+    Video_TimeStamp_FirstFrame_String4,
+    Video_TimeStamp_FirstFrame_String5,
     Video_TimeCode_FirstFrame,
     Video_TimeCode_Settings,
     Video_TimeCode_Source,
+    Video_Gop_OpenClosed,
+    Video_Gop_OpenClosed_String,
+    Video_Gop_OpenClosed_FirstFrame,
+    Video_Gop_OpenClosed_FirstFrame_String,
     Video_StreamSize,
     Video_StreamSize_String,
     Video_StreamSize_String1,
@@ -708,6 +748,7 @@ enum video
     Video_colour_primaries,
     Video_transfer_characteristics,
     Video_matrix_coefficients,
+    Video_colour_range,
     Video_colour_description_present_Original,
     Video_colour_primaries_Original,
     Video_transfer_characteristics_Original,
@@ -787,31 +828,43 @@ enum audio
     Audio_Duration_String1,
     Audio_Duration_String2,
     Audio_Duration_String3,
+    Audio_Duration_String4,
+    Audio_Duration_String5,
     Audio_Duration_FirstFrame,
     Audio_Duration_FirstFrame_String,
     Audio_Duration_FirstFrame_String1,
     Audio_Duration_FirstFrame_String2,
     Audio_Duration_FirstFrame_String3,
+    Audio_Duration_FirstFrame_String4,
+    Audio_Duration_FirstFrame_String5,
     Audio_Duration_LastFrame,
     Audio_Duration_LastFrame_String,
     Audio_Duration_LastFrame_String1,
     Audio_Duration_LastFrame_String2,
     Audio_Duration_LastFrame_String3,
+    Audio_Duration_LastFrame_String4,
+    Audio_Duration_LastFrame_String5,
     Audio_Source_Duration,
     Audio_Source_Duration_String,
     Audio_Source_Duration_String1,
     Audio_Source_Duration_String2,
     Audio_Source_Duration_String3,
+    Audio_Source_Duration_String4,
+    Audio_Source_Duration_String5,
     Audio_Source_Duration_FirstFrame,
     Audio_Source_Duration_FirstFrame_String,
     Audio_Source_Duration_FirstFrame_String1,
     Audio_Source_Duration_FirstFrame_String2,
     Audio_Source_Duration_FirstFrame_String3,
+    Audio_Source_Duration_FirstFrame_String4,
+    Audio_Source_Duration_FirstFrame_String5,
     Audio_Source_Duration_LastFrame,
     Audio_Source_Duration_LastFrame_String,
     Audio_Source_Duration_LastFrame_String1,
     Audio_Source_Duration_LastFrame_String2,
     Audio_Source_Duration_LastFrame_String3,
+    Audio_Source_Duration_LastFrame_String4,
+    Audio_Source_Duration_LastFrame_String5,
     Audio_BitRate_Mode,
     Audio_BitRate_Mode_String,
     Audio_BitRate,
@@ -859,6 +912,7 @@ enum audio
     Audio_Delay_String2,
     Audio_Delay_String3,
     Audio_Delay_String4,
+    Audio_Delay_String5,
     Audio_Delay_Settings,
     Audio_Delay_DropFrame,
     Audio_Delay_Source,
@@ -869,6 +923,7 @@ enum audio
     Audio_Delay_Original_String2,
     Audio_Delay_Original_String3,
     Audio_Delay_Original_String4,
+    Audio_Delay_Original_String5,
     Audio_Delay_Original_Settings,
     Audio_Delay_Original_DropFrame,
     Audio_Delay_Original_Source,
@@ -878,12 +933,14 @@ enum audio
     Audio_Video_Delay_String2,
     Audio_Video_Delay_String3,
     Audio_Video_Delay_String4,
+    Audio_Video_Delay_String5,
     Audio_Video0_Delay,
     Audio_Video0_Delay_String,
     Audio_Video0_Delay_String1,
     Audio_Video0_Delay_String2,
     Audio_Video0_Delay_String3,
     Audio_Video0_Delay_String4,
+    Audio_Video0_Delay_String5,
     Audio_ReplayGain_Gain,
     Audio_ReplayGain_Gain_String,
     Audio_ReplayGain_Peak,
@@ -998,31 +1055,42 @@ enum text
     Text_Duration_String2,
     Text_Duration_String3,
     Text_Duration_String4,
+    Text_Duration_String5,
     Text_Duration_FirstFrame,
     Text_Duration_FirstFrame_String,
     Text_Duration_FirstFrame_String1,
     Text_Duration_FirstFrame_String2,
     Text_Duration_FirstFrame_String3,
+    Text_Duration_FirstFrame_String4,
+    Text_Duration_FirstFrame_String5,
     Text_Duration_LastFrame,
     Text_Duration_LastFrame_String,
     Text_Duration_LastFrame_String1,
     Text_Duration_LastFrame_String2,
     Text_Duration_LastFrame_String3,
+    Text_Duration_LastFrame_String4,
+    Text_Duration_LastFrame_String5,
     Text_Source_Duration,
     Text_Source_Duration_String,
     Text_Source_Duration_String1,
     Text_Source_Duration_String2,
     Text_Source_Duration_String3,
+    Text_Source_Duration_String4,
+    Text_Source_Duration_String5,
     Text_Source_Duration_FirstFrame,
     Text_Source_Duration_FirstFrame_String,
     Text_Source_Duration_FirstFrame_String1,
     Text_Source_Duration_FirstFrame_String2,
     Text_Source_Duration_FirstFrame_String3,
+    Text_Source_Duration_FirstFrame_String4,
+    Text_Source_Duration_FirstFrame_String5,
     Text_Source_Duration_LastFrame,
     Text_Source_Duration_LastFrame_String,
     Text_Source_Duration_LastFrame_String1,
     Text_Source_Duration_LastFrame_String2,
     Text_Source_Duration_LastFrame_String3,
+    Text_Source_Duration_LastFrame_String4,
+    Text_Source_Duration_LastFrame_String5,
     Text_BitRate_Mode,
     Text_BitRate_Mode_String,
     Text_BitRate,
@@ -1068,6 +1136,7 @@ enum text
     Text_Delay_String2,
     Text_Delay_String3,
     Text_Delay_String4,
+    Text_Delay_String5,
     Text_Delay_Settings,
     Text_Delay_DropFrame,
     Text_Delay_Source,
@@ -1078,6 +1147,7 @@ enum text
     Text_Delay_Original_String2,
     Text_Delay_Original_String3,
     Text_Delay_Original_String4,
+    Text_Delay_Original_String5,
     Text_Delay_Original_Settings,
     Text_Delay_Original_DropFrame,
     Text_Delay_Original_Source,
@@ -1087,12 +1157,14 @@ enum text
     Text_Video_Delay_String2,
     Text_Video_Delay_String3,
     Text_Video_Delay_String4,
+    Text_Video_Delay_String5,
     Text_Video0_Delay,
     Text_Video0_Delay_String,
     Text_Video0_Delay_String1,
     Text_Video0_Delay_String2,
     Text_Video0_Delay_String3,
     Text_Video0_Delay_String4,
+    Text_Video0_Delay_String5,
     Text_StreamSize,
     Text_StreamSize_String,
     Text_StreamSize_String1,
@@ -1190,6 +1262,8 @@ enum other
     Other_Duration_String1,
     Other_Duration_String2,
     Other_Duration_String3,
+    Other_Duration_String4,
+    Other_Duration_String5,
     Other_Duration_Start,
     Other_Duration_End,
     Other_FrameRate,
@@ -1200,8 +1274,12 @@ enum other
     Other_TimeStamp_FirstFrame_String1,
     Other_TimeStamp_FirstFrame_String2,
     Other_TimeStamp_FirstFrame_String3,
+    Other_TimeStamp_FirstFrame_String4,
+    Other_TimeStamp_FirstFrame_String5,
     Other_TimeCode_FirstFrame,
     Other_TimeCode_Settings,
+    Other_TimeCode_Striped,
+    Other_TimeCode_Striped_String,
     Other_Title,
     Other_Language,
     Other_Language_String,
@@ -1365,6 +1443,8 @@ enum menu
     Menu_Duration_String1,
     Menu_Duration_String2,
     Menu_Duration_String3,
+    Menu_Duration_String4,
+    Menu_Duration_String5,
     Menu_Duration_Start,
     Menu_Duration_End,
     Menu_Delay,
@@ -1373,6 +1453,7 @@ enum menu
     Menu_Delay_String2,
     Menu_Delay_String3,
     Menu_Delay_String4,
+    Menu_Delay_String5,
     Menu_Delay_Settings,
     Menu_Delay_DropFrame,
     Menu_Delay_Source,
